instrumenttools.Contrabassoon
=============================

.. abjad-lineage:: abjad.tools.instrumenttools.Contrabassoon.Contrabassoon.Contrabassoon

.. autoclass:: abjad.tools.instrumenttools.Contrabassoon.Contrabassoon.Contrabassoon
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.instrumenttools.Contrabassoon.Contrabassoon.Contrabassoon.default_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Contrabassoon.Contrabassoon.Contrabassoon.default_short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Contrabassoon.Contrabassoon.Contrabassoon.effective_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Contrabassoon.Contrabassoon.Contrabassoon.interval_of_transposition
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Contrabassoon.Contrabassoon.Contrabassoon.is_primary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Contrabassoon.Contrabassoon.Contrabassoon.is_secondary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Contrabassoon.Contrabassoon.Contrabassoon.is_transposing
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Contrabassoon.Contrabassoon.Contrabassoon.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Contrabassoon.Contrabassoon.Contrabassoon.start_component
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Contrabassoon.Contrabassoon.Contrabassoon.storage_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Contrabassoon.Contrabassoon.Contrabassoon.target_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Contrabassoon.Contrabassoon.Contrabassoon.traditional_pitch_range
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.instrumenttools.Contrabassoon.Contrabassoon.Contrabassoon.all_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Contrabassoon.Contrabassoon.Contrabassoon.instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Contrabassoon.Contrabassoon.Contrabassoon.instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Contrabassoon.Contrabassoon.Contrabassoon.pitch_range
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Contrabassoon.Contrabassoon.Contrabassoon.primary_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Contrabassoon.Contrabassoon.Contrabassoon.short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Contrabassoon.Contrabassoon.Contrabassoon.short_instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Contrabassoon.Contrabassoon.Contrabassoon.sounding_pitch_of_fingered_middle_c
   :noindex:

Methods
-------

.. automethod:: abjad.tools.instrumenttools.Contrabassoon.Contrabassoon.Contrabassoon.attach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Contrabassoon.Contrabassoon.Contrabassoon.detach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Contrabassoon.Contrabassoon.Contrabassoon.get_default_performer_name
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Contrabassoon.Contrabassoon.Contrabassoon.get_performer_names
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.instrumenttools.Contrabassoon.Contrabassoon.Contrabassoon.__call__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Contrabassoon.Contrabassoon.Contrabassoon.__delattr__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Contrabassoon.Contrabassoon.Contrabassoon.__eq__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Contrabassoon.Contrabassoon.Contrabassoon.__ge__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Contrabassoon.Contrabassoon.Contrabassoon.__gt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Contrabassoon.Contrabassoon.Contrabassoon.__hash__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Contrabassoon.Contrabassoon.Contrabassoon.__le__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Contrabassoon.Contrabassoon.Contrabassoon.__lt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Contrabassoon.Contrabassoon.Contrabassoon.__ne__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Contrabassoon.Contrabassoon.Contrabassoon.__repr__
   :noindex:
